@@ -2,7 +2,7 @@
 
 # Imports 
 import sys
-sys.path.insert(0, 'PROGRAMS/pyranges/') #On drac
+#sys.path.insert(0, 'PROGRAMS/pyranges/') #On drac
 
 import pyranges as pr
 import pyranges.out as out ####################################################################################################################### I DID NOT FIND ANY OTHER WAY TO DO THIS
@@ -12,6 +12,10 @@ import pandas as pd
 import copy
 from easyterm import *
 
+__all__=['extend_orfs','mod_genome_bounds', '_outside_bounds_j',
+         'mod_get_sequence','find_upstream_patterns','find_downstream_patterns',
+         'filler','mod_extend','_extend_grp_j','mod_to_gff3'] ################################################################################################################### WORKING HERE
+
 def_opt={'p':'',
          'clean_p':False, 
          'fasta_path':'',
